/*
    LibGViewer - GTK+ File Viewer library 
    Copyright (C) 2006 Assaf Gordon
    
    Part of
        GNOME Commander - A GNOME based file manager
        Copyright (C) 2001-2006 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef __LIB_GVIEWER_H__
#define __LIB_GVIEWER_H__

#include <gtk/gtk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtktable.h>

#include "gvtypes.h"
#include "viewer-utils.h"
#include "fileops.h"
#include "inputmodes.h"
#include "datapresentation.h"
#include "scroll-box.h"
#include "image-render.h"
#include "text-render.h"
#include "viewer-widget.h"
#include "viewer-window.h"
#include "search-dlg.h"
#include "searcher.h"
#include "search-progress-dlg.h"

#endif
